@@ -1,14 +1,12 @@
 import os
 import cv2
 import numpy as np
-from plantcv.plantcv import print_image
-from plantcv.plantcv import plot_image
+from plantcv.plantcv._debug import _debug
 from plantcv.plantcv import color_palette
 from plantcv.plantcv import params
 
 
 def cluster_contours(img, roi_objects, roi_obj_hierarchy, nrow=1, ncol=1, show_grid=False):
-
     """
     This function take a image with multiple contours and clusters them based on user input of rows and columns
 
@@ -37,8 +35,6 @@ def cluster_contours(img, roi_objects, roi_obj_hierarchy, nrow=1, ncol=1, show_g
     :return roi_obj_hierarchy: list
     """
 
-    params.device += 1
-
     if len(np.shape(img)) == 3:
         iy, ix, iz = np.shape(img)
     else:
@@ -49,13 +45,13 @@ def cluster_contours(img, roi_objects, roi_obj_hierarchy, nrow=1, ncol=1, show_g
         rbreaks = [0, iy]
     else:
         rstep = np.rint(iy / nrow)
-        rstep1 = np.int(rstep)
+        rstep1 = int(rstep)
         rbreaks = range(0, iy, rstep1)
     if ncol == 1:
         cbreaks = [0, ix]
     else:
         cstep = np.rint(ix / ncol)
-        cstep1 = np.int(cstep)
+        cstep1 = int(cstep)
         cbreaks = range(0, ix, cstep1)
 
     # categorize what bin the center of mass of each contour
@@ -140,9 +136,10 @@ def cluster_contours(img, roi_objects, roi_obj_hierarchy, nrow=1, ncol=1, show_g
                 cv2.line(img_copy, (0, y), (ix, y), (255, 0, 0), params.line_thickness)
             for x in cbreaks:
                 cv2.line(img_copy, (x, 0), (x, iy), (255, 0, 0), params.line_thickness)
-        if params.debug == 'print':
-            print_image(img_copy, os.path.join(params.debug_outdir, str(params.device) + '_clusters.png'))
-        elif params.debug == 'plot':
-            plot_image(img_copy)
+    else:
+        img_copy = img  # for _debug
+
+    _debug(visual=img_copy,  # keep this outside if statement to avoid additional test
+           filename=os.path.join(params.debug_outdir, str(params.device) + '_clusters.png'))
 
     return grouped_contour_indexes, contours, roi_obj_hierarchy
