@@ -1,7 +1,6 @@
 # Image subtraction
 
-from plantcv.plantcv import print_image
-from plantcv.plantcv import plot_image
+from plantcv.plantcv._debug import _debug
 from plantcv.plantcv import params
 from plantcv.plantcv import fatal_error
 import numpy as np
@@ -9,7 +8,8 @@ import os
 
 
 def image_subtract(gray_img1, gray_img2):
-    """This is a function used to subtract values of one gray-scale image array from another gray-scale image array. The
+    """
+    This is a function used to subtract values of one gray-scale image array from another gray-scale image array. The
     resulting gray-scale image array has a minimum element value of zero. That is all negative values resulting from the
     subtraction are forced to zero.
 
@@ -25,8 +25,6 @@ def image_subtract(gray_img1, gray_img2):
     :return new_img: numpy.ndarray
     """
 
-    params.device += 1  # increment device
-
     # check inputs for gray-scale
     if len(np.shape(gray_img1)) != 2 or len(np.shape(gray_img2)) != 2:
         fatal_error("Input image is not gray-scale")
@@ -34,9 +32,9 @@ def image_subtract(gray_img1, gray_img2):
     new_img = gray_img1.astype(np.float64) - gray_img2.astype(np.float64)  # subtract values
     new_img[np.where(new_img < 0)] = 0  # force negative array values to zero
     new_img = new_img.astype(np.uint8)  # typecast image to 8-bit image
-    # print-plot handling
-    if params.debug == 'print':
-        print_image(new_img, os.path.join(params.debug_outdir, str(params.device) + "_subtraction.png"))
-    elif params.debug == 'plot':
-        plot_image(new_img, cmap='gray')
+
+    _debug(visual=new_img,
+           filename=os.path.join(params.debug_outdir, str(params.device) + "_subtraction.png"),
+           cmap='gray')
+
     return new_img  # return
