@@ -2,13 +2,13 @@
 
 import cv2
 import os
-from plantcv.plantcv import print_image
-from plantcv.plantcv import plot_image
+from plantcv.plantcv._debug import _debug
 from plantcv.plantcv import params
 
 
 def logical_xor(bin_img1, bin_img2):
-    """Join two images using the bitwise XOR operator.
+    """
+    Join two images using the bitwise XOR operator.
 
     Inputs:
     bin_img1   = Binary image data to be compared to bin_img2
@@ -22,10 +22,10 @@ def logical_xor(bin_img1, bin_img2):
     :return merged: numpy.ndarray
     """
 
-    params.device += 1
     merged = cv2.bitwise_xor(bin_img1, bin_img2)
-    if params.debug == 'print':
-        print_image(merged, os.path.join(params.debug_outdir, str(params.device) + '_xor_joined.png'))
-    elif params.debug == 'plot':
-        plot_image(merged, cmap='gray')
+
+    _debug(visual=merged,
+           filename=os.path.join(params.debug_outdir, str(params.device) + '_xor_joined.png'),
+           cmap='gray')
+
     return merged
