@@ -14,13 +14,14 @@ from plantcv.plantcv.morphology import segment_path_length
 from plantcv.plantcv.morphology import segment_euclidean_length
 
 
-def segment_curvature(segmented_img, objects):
+def segment_curvature(segmented_img, objects, label="default"):
     """ Calculate segment curvature as defined by the ratio between geodesic and euclidean distance.
         Measurement of two-dimensional tortuosity.
 
         Inputs:
         segmented_img     = Segmented image to plot lengths on
         objects           = List of contours
+        label          = optional label parameter, modifies the variable name of observations recorded
 
         Returns:
         labeled_img        = Segmented debugging image with curvature labeled
@@ -28,6 +29,7 @@ def segment_curvature(segmented_img, objects):
 
         :param segmented_img: numpy.ndarray
         :param objects: list
+        :param label: str
         :return labeled_img: numpy.ndarray
 
         """
@@ -40,10 +42,10 @@ def segment_curvature(segmented_img, objects):
     debug = params.debug
     params.debug = None
 
-    _ = segment_euclidean_length(segmented_img, objects)
-    _ = segment_path_length(segmented_img, objects)
-    eu_lengths = outputs.observations['segment_eu_length']['value']
-    path_lengths = outputs.observations['segment_path_length']['value']
+    _ = segment_euclidean_length(segmented_img, objects, label="backend")
+    _ = segment_path_length(segmented_img, objects, label="backend")
+    eu_lengths = outputs.observations['backend']['segment_eu_length']['value']
+    path_lengths = outputs.observations['backend']['segment_path_length']['value']
     curvature_measure = [float(x / y) for x, y in zip(path_lengths, eu_lengths)]
     # Create a color scale, use a previously stored scale if available
     rand_color = color_palette(num=len(objects), saved=True)
@@ -83,7 +85,7 @@ def segment_curvature(segmented_img, objects):
         # segment_label = "ID" + str(i)
         segment_ids.append(i)
 
-    outputs.add_observation(variable='segment_curvature', trait='segment curvature',
+    outputs.add_observation(sample=label, variable='segment_curvature', trait='segment curvature',
                             method='plantcv.plantcv.morphology.segment_curvature', scale='none', datatype=list,
                             value=curvature_measure, label=segment_ids)
 
