@@ -14,18 +14,20 @@ from scipy.spatial.distance import euclidean
 from plantcv.plantcv.morphology import find_tips
 
 
-def segment_euclidean_length(segmented_img, objects):
+def segment_euclidean_length(segmented_img, objects, label="default"):
     """ Use segmented skeleton image to gather euclidean length measurements per segment
 
         Inputs:
         segmented_img = Segmented image to plot lengths on
         objects       = List of contours
+        label         = optional label parameter, modifies the variable name of observations recorded
 
         Returns:
         labeled_img      = Segmented debugging image with lengths labeled
 
         :param segmented_img: numpy.ndarray
         :param objects: list
+        :param label: str
         :return labeled_img: numpy.ndarray
 
         """
@@ -79,7 +81,7 @@ def segment_euclidean_length(segmented_img, objects):
         # segment_label = "ID" + str(c)
         segment_ids.append(c)
 
-    outputs.add_observation(variable='segment_eu_length', trait='segment euclidean length',
+    outputs.add_observation(sample=label, variable='segment_eu_length', trait='segment euclidean length',
                             method='plantcv.plantcv.morphology.segment_euclidean_length', scale='pixels', datatype=list,
                             value=segment_lengths, label=segment_ids)
 
