@@ -29,7 +29,7 @@ def print_image(img, filename):
 
     # Print ggplot type images
     elif str(image_type) == "<class 'plotnine.ggplot.ggplot'>":
-        img.save(filename)
+        img.save(filename, verbose=False)
 
     else:
         fatal_error("Error writing file " + filename + ": input img is " + str(type(img)) + ", not a numpy.ndarray, " +
