@@ -36,6 +36,9 @@ def get_color_matrix(rgb_img, mask):
     if len(np.shape(mask)) != 2:
         fatal_error("Input mask is not an gray-scale image.")
 
+    # convert to float and normalize to work with values between 0-1
+    rgb_img = rgb_img.astype(np.float64)/255
+
     # create empty color_matrix
     color_matrix = np.zeros((len(np.unique(mask))-1, 4))
 
@@ -113,7 +116,7 @@ def get_matrix_m(target_matrix, source_matrix):
     s_b3 = np.power(s_b, 3)
 
     # create matrix_a
-    matrix_a = np.concatenate((s_r, s_g, s_b, s_b2, s_g2, s_r2, s_b3, s_g3, s_r3), 1)
+    matrix_a = np.concatenate((s_r, s_g, s_b, s_r2, s_g2, s_b2, s_r3, s_g3, s_b3), 1)
     # create matrix_m
     matrix_m = np.linalg.solve(np.matmul(matrix_a.T, matrix_a), matrix_a.T)
     # create matrix_b
@@ -205,6 +208,8 @@ def apply_transformation_matrix(source_img, target_img, transformation_matrix):
     # split transformation_matrix
     red, green, blue, red2, green2, blue2, red3, green3, blue3 = np.split(transformation_matrix, 9, 1)
 
+    # convert img to float to avoid integer overflow, normalize between 0-1
+    source_img = source_img.astype(np.float64)/255
     # find linear, square, and cubic values of source_img color channels
     source_b, source_g, source_r = cv2.split(source_img)
     source_b2 = np.square(source_b)
@@ -226,9 +231,10 @@ def apply_transformation_matrix(source_img, target_img, transformation_matrix):
     bgr = [b, g, r]
     corrected_img = cv2.merge(bgr)
 
-    # round corrected_img elements to be within range and of the correct data type
-    corrected_img = np.rint(corrected_img)
-    corrected_img[np.where(corrected_img > 255)] = 255
+    # return values of the image to the 0-255 range
+    corrected_img = 255*np.clip(corrected_img, 0, 1)
+    corrected_img = np.floor(corrected_img)
+    # cast back to unsigned int
     corrected_img = corrected_img.astype(np.uint8)
 
     if params.debug == "print":
@@ -237,6 +243,8 @@ def apply_transformation_matrix(source_img, target_img, transformation_matrix):
     elif params.debug == "plot":
         # If debug is plot, print a horizontal view of source_img, corrected_img, and target_img to the plotting device
         # plot horizontal comparison of source_img, corrected_img (with rounded elements) and target_img
+        # cast source_img back to unsigned int between 0-255 for visualization
+        source_img = (255*source_img).astype(np.uint8)
         plot_image(np.hstack([source_img, corrected_img, target_img]))
 
     # return corrected_img
@@ -359,6 +367,9 @@ def create_color_card_mask(rgb_img, radius, start_coord, spacing, nrows, ncols,
     params.device += 1
     # Initialize chip list
     chips = []
+    # Store debug mode
+    debug = params.debug
+    params.debug = None
 
     # Loop over each color card row
     for i in range(0, nrows):
@@ -371,6 +382,8 @@ def create_color_card_mask(rgb_img, radius, start_coord, spacing, nrows, ncols,
             x = start_coord[0] + j * spacing[0]
             # Create a chip ROI
             chips.append(circle(img=rgb_img, x=x, y=y, r=radius))
+    # Restore debug parameter
+    params.debug = debug
     # Sort excluded chips from largest to smallest
     exclude.sort(reverse=True)
     # Remove any excluded chips
@@ -420,6 +433,10 @@ def quick_color_check(target_matrix, source_matrix, num_chips):
         scale_y_continuous, scale_color_manual, aes
     import pandas as pd
 
+    # Scale matrices back to 0-255
+    target_matrix = 255*target_matrix
+    source_matrix = 255*source_matrix
+
     # Extract and organize matrix info
     tr = target_matrix[:num_chips, 1:2]
     tg = target_matrix[:num_chips, 2:3]
@@ -470,13 +487,13 @@ def quick_color_check(target_matrix, source_matrix, num_chips):
     # Reset debug
     if params.debug is not None:
         if params.debug == 'print':
-            p1.save(os.path.join(params.debug_outdir, 'color_quick_check.png'))
+            p1.save(os.path.join(params.debug_outdir, 'color_quick_check.png'), verbose=False)
         elif params.debug == 'plot':
             print(p1)
 
 
 def find_color_card(rgb_img, threshold_type='adaptgauss', threshvalue=125, blurry=False, background='dark',
-                    record_chip_size="median"):
+                    record_chip_size="median", label="default"):
     """Automatically detects a color card and output info to use in create_color_card_mask function
 
     Algorithm written by Brandon Hurr. Updated and implemented into PlantCV by Haley Schuhl.
@@ -491,6 +508,7 @@ def find_color_card(rgb_img, threshold_type='adaptgauss', threshvalue=125, blurr
                         is a dark background
     record_chip_size = Optional str for choosing chip size measurement to be recorded, either "median",
                         "mean", or None
+    label            = optional label parameter, modifies the variable name of observations recorded (default 'default')
 
     Returns:
     df             = Dataframe containing information about the filtered contours
@@ -503,6 +521,7 @@ def find_color_card(rgb_img, threshold_type='adaptgauss', threshvalue=125, blurr
     :param blurry: bool
     :param background: str
     :param record_chip_size: str
+    :param label: str
     :return df: pandas.core.frame.DataFrame
     :return start_coord: tuple
     :return spacing: tuple
@@ -756,14 +775,16 @@ def find_color_card(rgb_img, threshold_type='adaptgauss', threshvalue=125, blurr
             chip_height = None
             chip_width = None
         # Store into global measurements
-        outputs.add_observation(variable='color_chip_size', trait='size of color card chips identified',
+        outputs.add_observation(sample=label, variable='color_chip_size', trait='size of color card chips identified',
                                 method='plantcv.plantcv.transform.find_color_card', scale='none',
                                 datatype=float, value=chip_size, label=str(record_chip_size))
         method = record_chip_size.lower()
-        outputs.add_observation(variable=f'{method}_color_chip_height', trait=f'{method} height of color card chips identified',
+        outputs.add_observation(sample=label, variable=f'{method}_color_chip_height',
+                                trait=f'{method} height of color card chips identified',
                                 method='plantcv.plantcv.transform.find_color_card', scale='none',
                                 datatype=float, value=chip_height, label=str(record_chip_size))
-        outputs.add_observation(variable=f'{method}_color_chip_width', trait=f'{method} size of color card chips identified',
+        outputs.add_observation(sample=label, variable=f'{method}_color_chip_width',
+                                trait=f'{method} size of color card chips identified',
                                 method='plantcv.plantcv.transform.find_color_card', scale='none',
                                 datatype=float, value=chip_width, label=str(record_chip_size))
 
